.. comment:
    SPDX-FileCopyrightText: 2017-2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
    SPDX-License-Identifier: MPL-2.0

.. _community:

.. toctree::
   :hidden:
   :maxdepth: 1

   license
   citing

Community
=========
Here you can find all information about the OpenSTEF community.

.. include:: committee.rst

.. include:: maintainers.rst


Roadmap
-------
An actual overview of the OpenSTEF roadmap can be found in the `OpenSTEF roadmap documentation <https://wiki.lfenergy.org/display/OS/OpenSTEF+Roadmap>`_.

Contributing
------------
OpenSTEF welcomes contributions in all forms!

For contributing guidelines, see our :ref:`contributing` guide.

If you found a bug or would like to request a feature, please `open an issue <https://github.com/OpenSTEF/openstef/issues>`_.

During the four-weekly community meetings, we discuss progress, refine open issues, and explore collaboration possibilities. This meeting is open for anyone that is interested. More details and meeting links can be found in the `community meetings documentation <https://wiki.lfenergy.org/display/OS/Biweekly+Refinement>`_.

.. include:: support.rst
